@@ -25,8 +25,6 @@ if __name__ == '__main__':
 
     request = ezio_pb2.AddRequest()
     request.save_path = sys.argv[2]
-    request.max_uploads = 2
-    request.max_connections = 2
     with open(sys.argv[1], 'rb') as f:
         request.torrent = f.read()
 
